@@ -14,8 +14,32 @@ from django_components.component_registry import AlreadyRegistered, ComponentReg
 
 TEMPLATE_CACHE_SIZE = getattr(settings, "COMPONENTS", {}).get('TEMPLATE_CACHE_SIZE', 128)
 
+class SimplifiedInterfaceMediaDefiningClass(MediaDefiningClass):
+    def __new__(mcs, name, bases, attrs):
+        if "Media" in attrs:
+            media = attrs["Media"]
 
-class Component(metaclass=MediaDefiningClass):
+            # Allow: class Media: css = "style.css"
+            if isinstance(media.css, str):
+                media.css = [media.css]
+
+            # Allow: class Media: css = ["style.css"]
+            if isinstance(media.css, list):
+                media.css = {"all": media.css}
+
+            # Allow: class Media: css = {"all": "style.css"}
+            if isinstance(media.css, dict):
+                for media_type, path_list in media.css.items():
+                    if isinstance(path_list, str):
+                        media.css[media_type] = [path_list]
+
+            # Allow: class Media: js = "script.js"
+            if isinstance(media.js, str):
+                media.js = [media.js]
+
+        return super().__new__(mcs, name, bases, attrs)
+
+class Component(metaclass=SimplifiedInterfaceMediaDefiningClass):
 
     def __init__(self, component_name):
         self.__component_name = component_name
@@ -45,7 +69,11 @@ class Component(metaclass=MediaDefiningClass):
 
     @staticmethod
     def slots_in_template(template):
-        return {node.name: node.nodelist for node in template.template.nodelist if is_slot_node(node)}
+        return {node.name: node.nodelist for node in template.template.nodelist if Component.is_slot_node(node)}
+
+    @staticmethod
+    def is_slot_node(node):
+        return node.token.token_type == TokenType.BLOCK and node.token.split_contents()[0] == "slot"
 
     @lru_cache(maxsize=TEMPLATE_CACHE_SIZE)
     def compile_instance_template(self, template_name):
@@ -53,7 +81,7 @@ class Component(metaclass=MediaDefiningClass):
         a unified template for this instance."""
 
         component_template = get_template(template_name)
-        slots_in_template = self.slots_in_template(component_template)
+        slots_in_template = Component.slots_in_template(component_template)
 
         defined_slot_names = set(slots_in_template.keys())
         filled_slot_names = set(self.slots.keys())
@@ -71,7 +99,7 @@ class Component(metaclass=MediaDefiningClass):
         combined_slots = dict(slots_in_template, **self.slots)
         if combined_slots:
             # Replace slot nodes with their nodelists, then combine into a single, flat nodelist
-            node_iterator = ([node] if not is_slot_node(node) else combined_slots[node.name]
+            node_iterator = ([node] if not Component.is_slot_node(node) else combined_slots[node.name]
                              for node in component_template.template.nodelist)
 
             instance_template = copy(component_template.template)
@@ -91,10 +119,6 @@ class Component(metaclass=MediaDefiningClass):
         js = []
 
 
-def is_slot_node(node):
-    return node.token.token_type == TokenType.BLOCK and node.token.split_contents()[0] == "slot"
-
-
 # This variable represents the global component registry
 registry = ComponentRegistry()
 
